@@ -53,6 +53,7 @@ class LowQualityBlastError(Exception):
     search. This error should be raised for the BLAST reports produced
     in this case.
     """
+
     pass
 
 
@@ -68,6 +69,7 @@ class ShortQueryBlastError(Exception):
 
     This exception is raised when that condition is detected.
     """
+
     pass
 
 
@@ -78,7 +80,9 @@ class _Scanner(object):
 
     Methods:
      - feed     Feed data into the scanner.
+
     """
+
     def feed(self, handle, consumer):
         """S.feed(handle, consumer)
 
@@ -153,7 +157,7 @@ class _Scanner(object):
 
         # Read the reference(s)
         while attempt_read_and_call(uhandle,
-                                consumer.reference, start='Reference'):
+                                    consumer.reference, start='Reference'):
             # References are normally multiline terminated by a blank line
             # (or, based on the old code, the RID line)
             while True:
@@ -275,7 +279,7 @@ class _Scanner(object):
         # If this happens, the handle will yield no more information.
         if not uhandle.peekline():
             raise ValueError("Unexpected end of blast report.  " +
-                  "Looks suspiciously like a PSI-BLAST crash.")
+                             "Looks suspiciously like a PSI-BLAST crash.")
 
         # BLASTN 2.2.3 sometimes spews a bunch of warnings and errors here:
         # Searching[blastall] WARNING:  [000.000]  AT1G08320: SetUpBlastSearch
@@ -438,8 +442,7 @@ class _Scanner(object):
         read_and_call(uhandle, consumer.title, start='>')
         while True:
             line = safe_readline(uhandle)
-            if line.lstrip().startswith('Length =') \
-            or line.lstrip().startswith('Length='):
+            if line.lstrip().startswith(('Length =', 'Length=')):
                 consumer.length(line)
                 break
             elif is_blank_line(line):
@@ -579,12 +582,12 @@ class _Scanner(object):
         # Sameet Mehta reported seeing output from BLASTN 2.2.9 that
         # was missing the "Database" stanza completely.
         while attempt_read_and_call(uhandle, consumer.database,
-                start='  Database'):
+                                    start='  Database'):
             # BLAT output ends abruptly here, without any of the other
             # information.  Check to see if this is the case.  If so,
             # then end the database report here gracefully.
-            if not uhandle.peekline().strip() \
-            or uhandle.peekline().startswith("BLAST"):
+            if not uhandle.peekline().strip() or \
+                    uhandle.peekline().startswith("BLAST"):
                 consumer.end_database_report()
                 return
 
@@ -592,9 +595,9 @@ class _Scanner(object):
             read_and_call_until(uhandle, consumer.database, start='    Posted')
             read_and_call(uhandle, consumer.posted_date, start='    Posted')
             read_and_call(uhandle, consumer.num_letters_in_database,
-                       start='  Number of letters')
+                          start='  Number of letters')
             read_and_call(uhandle, consumer.num_sequences_in_database,
-                       start='  Number of sequences')
+                          start='  Number of sequences')
             # There may not be a line starting with spaces...
             attempt_read_and_call(uhandle, consumer.noevent, start='  ')
 
@@ -700,16 +703,16 @@ class _Scanner(object):
         attempt_read_and_call(uhandle, consumer.num_sequences,
                               start='Number of Sequences')
         attempt_read_and_call(uhandle, consumer.num_hits,
-                      start='Number of Hits')
+                              start='Number of Hits')
         attempt_read_and_call(uhandle, consumer.num_sequences,
                               start='Number of Sequences')
         attempt_read_and_call(uhandle, consumer.num_extends,
-                      start='Number of extensions')
+                              start='Number of extensions')
         attempt_read_and_call(uhandle, consumer.num_good_extends,
-                      start='Number of successful')
+                              start='Number of successful')
 
         attempt_read_and_call(uhandle, consumer.num_seqs_better_e,
-                      start='Number of sequences')
+                              start='Number of sequences')
 
         # not BLASTN, TBLASTX
         if attempt_read_and_call(uhandle, consumer.hsps_no_gap,
@@ -721,7 +724,7 @@ class _Scanner(object):
                               start="Number of HSP's successfully")
                 # This is omitted in 2.2.15
                 attempt_read_and_call(uhandle, consumer.noevent,
-                              start="Number of extra gapped extensions")
+                                      start="Number of extra gapped extensions")
             else:
                 read_and_call(uhandle, consumer.hsps_prelim_gapped,
                               start="Number of HSP's successfully")
@@ -731,7 +734,7 @@ class _Scanner(object):
                               start="Number of HSP's gapped")
         # e.g. BLASTX 2.2.15 where the "better" line is missing
         elif attempt_read_and_call(uhandle, consumer.noevent,
-                                     start="Number of HSP's gapped"):
+                                   start="Number of HSP's gapped"):
             read_and_call(uhandle, consumer.noevent,
                           start="Number of HSP's successfully")
 
@@ -740,7 +743,7 @@ class _Scanner(object):
                               has_re=re.compile(r"[Ll]ength of query"))
         # Not in BLASTX 2.2.22+
         attempt_read_and_call(uhandle, consumer.database_length,
-                          has_re=re.compile(r"[Ll]ength of \s*[Dd]atabase"))
+                              has_re=re.compile(r"[Ll]ength of \s*[Dd]atabase"))
 
         # BLASTN 2.2.9
         attempt_read_and_call(uhandle, consumer.noevent,
@@ -800,9 +803,8 @@ class _Scanner(object):
 
 
 class BlastParser(AbstractParser):
-    """Parses BLAST data into a Record.Blast object.
+    """Parses BLAST data into a Record.Blast object."""
 
-    """
     def __init__(self):
         """__init__(self)"""
         self._scanner = _Scanner()
@@ -815,9 +817,8 @@ class BlastParser(AbstractParser):
 
 
 class PSIBlastParser(AbstractParser):
-    """Parses BLAST data into a Record.PSIBlast object.
+    """Parses BLAST data into a Record.PSIBlast object."""
 
-    """
     def __init__(self):
         """__init__(self)"""
         self._scanner = _Scanner()
@@ -1423,28 +1424,32 @@ class _ParametersConsumer(object):
             self._params.effective_search_space_used)
 
     def frameshift(self, line):
-        self._params.frameshift = _get_cols(
-           line, (4, 5), ncols=6, expected={0: "frameshift", 2: "decay"})
+        self._params.frameshift = _get_cols(line, (4, 5), ncols=6,
+                                            expected={0: "frameshift", 2: "decay"})
 
     def threshold(self, line):
         if line[:2] == "T:":
             # Assume its an old style line like "T: 123"
-            self._params.threshold, = _get_cols(
-                line, (1,), ncols=2, expected={0: "T:"})
+            self._params.threshold, = _get_cols(line, (1,), ncols=2,
+                                                expected={0: "T:"})
         elif line[:28] == "Neighboring words threshold:":
-            self._params.threshold, = _get_cols(
-                line, (3,), ncols=4, expected={0: "Neighboring", 1: "words", 2: "threshold:"})
+            self._params.threshold, = _get_cols(line, (3,), ncols=4,
+                                                expected={0: "Neighboring",
+                                                          1: "words",
+                                                          2: "threshold:"})
         else:
             raise ValueError("Unrecognised threshold line:\n%s" % line)
         self._params.threshold = _safe_int(self._params.threshold)
 
     def window_size(self, line):
         if line[:2] == "A:":
-            self._params.window_size, = _get_cols(
-                line, (1,), ncols=2, expected={0: "A:"})
+            self._params.window_size, = _get_cols(line, (1,), ncols=2,
+                                                  expected={0: "A:"})
         elif line[:25] == "Window for multiple hits:":
-            self._params.window_size, = _get_cols(
-                line, (4,), ncols=5, expected={0: "Window", 2: "multiple", 3: "hits:"})
+            self._params.window_size, = _get_cols(line, (4,), ncols=5,
+                                                  expected={0: "Window",
+                                                            2: "multiple",
+                                                            3: "hits:"})
         else:
             raise ValueError("Unrecognised window size line:\n%s" % line)
         self._params.window_size = _safe_int(self._params.window_size)
@@ -1605,6 +1610,7 @@ class Iterator(object):
     next   Return the next record from the stream, or None.
 
     """
+
     def __init__(self, handle, parser=None):
         """__init__(self, handle, parser=None)
 
@@ -1628,7 +1634,6 @@ class Iterator(object):
 
         Return the next Blast record from the file.  If no more records,
         return None.
-
         """
         lines = []
         query = False
@@ -1769,7 +1774,7 @@ class BlastErrorParser(AbstractParser):
     that may actually indicate problems during BLAST parsing.
 
     Current BLAST problems this detects are:
-    o LowQualityBlastError - When BLASTing really low quality sequences
+    - LowQualityBlastError - When BLASTing really low quality sequences
     (ie. some GenBank entries which are just short stretches of a single
     nucleotide), BLAST will report an error with the sequence and be
     unable to search with this. This will lead to a badly formatted
@@ -1777,11 +1782,12 @@ class BlastErrorParser(AbstractParser):
     ValueError to a LowQualityBlastError and attempt to provide useful
     information.
     """
+
     def __init__(self, bad_report_handle=None):
         """Initialize a parser that tries to catch BlastErrors.
 
         Arguments:
-        o bad_report_handle - An optional argument specifying a handle
+        - bad_report_handle - An optional argument specifying a handle
         where bad reports should be sent. This would allow you to save
         all of the bad reports to a file, for instance. If no handle
         is specified, the bad reports will not be saved.
@@ -1793,8 +1799,7 @@ class BlastErrorParser(AbstractParser):
         self._consumer = _BlastErrorConsumer()
 
     def parse(self, handle):
-        """Parse a handle, attempting to diagnose errors.
-        """
+        """Parse a handle, attempting to diagnose errors."""
         results = handle.read()
 
         try:
@@ -1818,8 +1823,8 @@ class BlastErrorParser(AbstractParser):
         """Attempt to diagnose an error in the passed handle.
 
         Arguments:
-        o handle - The handle potentially containing the error
-        o data_record - The data record partially created by the consumer.
+        - handle - The handle potentially containing the error
+        - data_record - The data record partially created by the consumer.
         """
         line = handle.readline()
 
